==> mdm-rpc-0.1.30-sources.jar: com/chinayanghe/msp/mdm/vo/region/RegionVo.java <==
package com.chinayanghe.msp.mdm.vo.region;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by Administrator on 2017/5/11 0011.
 */
public class RegionVo implements Serializable {
    private static final long serialVersionUID = 1772782687507490918L;
    //主键
    private String id;
    //行政区域编码
    private String code;
    //行政区域名称
    private String name;
    //上级区域编码
    private String parentCode;
    //创建时间
    private Date createDate;
    //创建人ID
    private String createName;
    //修改时间
    private Date updateDate;
    //修改人
    private String updateName;
    //状态 0正常 1删除
    private Integer enableStatus;
    //区域层级AREA_LEVEL
    private Integer areaLevel;
    //操作类型AREA_LEVEL

    public Integer getAreaLevel() {
        return areaLevel;
    }

    public void setAreaLevel(Integer areaLevel) {
        this.areaLevel = areaLevel;
    }

    private String flag;

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getParentCode() {
        return parentCode;
    }

    public void setParentCode(String parentCode) {
        this.parentCode = parentCode;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public String getUpdateName() {
        return updateName;
    }

    public void setUpdateName(String updateName) {
        this.updateName = updateName;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public String getFlag() {
        return flag;
    }

    public void setFlag(String flag) {
        this.flag = flag;
    }
}

==> mdm-rpc-0.1.105-sources.jar: com/chinayanghe/msp/mdm/vo/region/RegionVo.java <==
package com.chinayanghe.msp.mdm.vo.region;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by Administrator on 2017/5/11 0011.
 */
public class RegionVo implements Serializable {
    private static final long serialVersionUID = 1772782687507490918L;
    //主键
    private String id;
    //行政区域编码
    private String code;
    //行政区域名称
    private String name;
    //上级区域编码
    private String parentCode;
    //创建时间
    private Date createDate;
    //创建人ID
    private String createName;
    //修改时间
    private Date updateDate;
    //修改人
    private String updateName;
    //状态 0正常 1删除
    private Integer enableStatus;
    //区域层级AREA_LEVEL
    private Integer areaLevel;
    //操作类型AREA_LEVEL
    //子区域
    private List<RegionVo> childRegions;

    public Integer getAreaLevel() {
        return areaLevel;
    }

    public void setAreaLevel(Integer areaLevel) {
        this.areaLevel = areaLevel;
    }

    private String flag;

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getParentCode() {
        return parentCode;
    }

    public void setParentCode(String parentCode) {
        this.parentCode = parentCode;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public String getUpdateName() {
        return updateName;
    }

    public void setUpdateName(String updateName) {
        this.updateName = updateName;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public String getFlag() {
        return flag;
    }

    public void setFlag(String flag) {
        this.flag = flag;
    }

    public List<RegionVo> getChildRegions() {
        return childRegions;
    }

    public void setChildRegions(List<RegionVo> childRegions) {
        this.childRegions = childRegions;
    }
}
